searchData={"items":[{"type":"module","title":"Kase","doc":"A module for converting strings and map keys between various casing styles.\n\nKäse simplifies the process of converting strings and map keys to different\ncasing formats, such as camelCase, snake_case, kebab-case, and more. This is\nespecially useful when working with APIs or data transformations, where consistent\ncasing is important.","ref":"Kase.html"},{"type":"module","title":"Features - Kase","doc":"- Convert strings to a specified casing style.\n  - Convert lists of strings to a specified casing style.\n  - Convert map keys to a specified casing style, including nested maps.\n  - Case-invariant string comparisons.\n  - Supports a wide variety of casing styles.","ref":"Kase.html#module-features"},{"type":"module","title":"Usage - Kase","doc":"","ref":"Kase.html#module-usage"},{"type":"module","title":"String Conversion - Kase","doc":"Convert a single string to a specified casing style:\n\n    iex> Kase.convert(\"this-variable-name\", :camel_case)\n    \"thisVariableName\"\n\nConvert a list of strings to a specified casing style:\n\n    iex> Kase.convert([\"kool-aid\", \"royalCrown\"], :snake_case)\n    [\"kool_aid\", \"royal_crown\"]","ref":"Kase.html#module-string-conversion"},{"type":"module","title":"Map Key Conversion - Kase","doc":"Convert the keys of a map to a specified casing style. This also supports nested\nmaps and the option to convert keys to atoms:\n\n    iex> map_input = %{\"first_key\" => \"value\", \"second_key\" => \"value\", \"nested_value\" => %{\"inner_key\" => \"value\"}}\n    iex> Kase.convert(map_input, :camel_case)\n    %{\"firstKey\" => \"value\", \"secondKey\" => \"value\", \"nestedValue\" => %{\"innerKey\" => \"value\"}}\n\n    iex> Kase.convert(map_input, :camel_case, to_atoms: true)\n    %{\"firstKey\": \"value\", \"secondKey\": \"value\", \"nestedValue\": %{\"innerKey\": \"value\"}}","ref":"Kase.html#module-map-key-conversion"},{"type":"module","title":"Case-Invariant Comparison - Kase","doc":"Compare two strings for equality, ignoring differences in casing:\n\n    iex> Kase.case_invariant_equal?(\"helloWorld\", \"hello_world\")\n    true\n\n    iex> Kase.case_invariant_equal?(\"fooBar\", \"FOO_BAR\")\n    true","ref":"Kase.html#module-case-invariant-comparison"},{"type":"module","title":"Supported Casing Styles - Kase","doc":"The following casing styles are supported:\n\n    - `:camel_case` - camelCase\n    - `:cobol_case` - COBOL-CASE\n    - `:dot_case` - dot.case\n    - `:flat_case` - flatcase\n    - `:humanized_case` - Humanized case\n    - `:kebab_case` - kebab-case\n    - `:pascal_case` - PascalCase\n    - `:snake_case` - snake_case\n    - `:train_case` - Train-Case\n    - `:upper_case_snake_case` - UPPER_CASE_SNAKE_CASE\n\nFor any custom conversions or additional casing styles, the `Kase.Conversor`\nmodule can be extended to handle these cases.","ref":"Kase.html#module-supported-casing-styles"},{"type":"function","title":"Kase.case_invariant_equal?/2","doc":"Compares two strings for equality, ignoring casing differences.","ref":"Kase.html#case_invariant_equal?/2"},{"type":"function","title":"Examples - Kase.case_invariant_equal?/2","doc":"iex> Kase.case_invariant_equal?(\"helloWorld\", \"hello_world\")\n    true\n\n    iex> Kase.case_invariant_equal?(\"fooBar\", \"FOO_BAR\")\n    true\n\n    iex> Kase.case_invariant_equal?(\"KaseLib\", \"case_lib\")\n    false","ref":"Kase.html#case_invariant_equal?/2-examples"},{"type":"function","title":"Kase.convert/2","doc":"Converts a given `string` to the specified `target_case`.","ref":"Kase.html#convert/2"},{"type":"function","title":"Examples - Kase.convert/2","doc":"iex> Kase.convert(\"this-variable-name\", :camel_case)\n    \"thisVariableName\"\n\n    iex> Kase.convert([\"kool-aid\", \"royalCrown\"], :snake_case)\n    [\"kool_aid\", \"royal_crown\"]","ref":"Kase.html#convert/2-examples"},{"type":"function","title":"Kase.convert/3","doc":"Converts the keys of a given `map` to the specified `target_case`.","ref":"Kase.html#convert/3"},{"type":"function","title":"Examples - Kase.convert/3","doc":"map_input = %{\"first_key\" => \"value\", \"second_key\" => \"value\", \"nested_value\" => %{\"inner_key\" => \"value\"}}\n    iex> Kase.convert(map_input, :camel_case)\n    %{\"firstKey\" => \"value\", \"secondKey\" => \"value\", \"nestedValue\" => %{\"innerKey\" => \"value\"}}\n\n    map_input = %{\"first_key\" => \"value\", \"second_key\" => \"value\"}\n    iex> Kase.convert(map_input, :camel_case, to_atoms: true)\n    %{\"firstKey\": \"value\", \"secondKey\": \"value\"}","ref":"Kase.html#convert/3-examples"},{"type":"function","title":"Kase.supported_casing_styles/0","doc":"","ref":"Kase.html#supported_casing_styles/0"},{"type":"type","title":"Kase.target_case/0","doc":"The target case to convert the string to.","ref":"Kase.html#t:target_case/0"},{"type":"module","title":"Kase.Conversor","doc":"A module for converting strings between different casing styles.","ref":"Kase.Conversor.html"},{"type":"function","title":"Kase.Conversor.convert/2","doc":"Converts a given `string` to the specified `target_case`.","ref":"Kase.Conversor.html#convert/2"},{"type":"function","title":"Examples - Kase.Conversor.convert/2","doc":"iex> Kase.convert(\"THIS-IS-COBOL-CASE\", :humanized_case)\n    \"This is cobol case\"\n\n    iex> Kase.convert(\"this-variable-name\", :camel_case)\n    \"thisVariableName\"\n\n    iex> Kase.convert(\"ThisIsPascalCase\", :snake_case)\n    \"this_is_pascal_case\"\n\n    iex> Kase.convert(\"snake_case_var\", :kebab_case)\n    \"snake-case-var\"\n\n    iex> Kase.convert(\"PascalCaseVar\", :upper_case_snake_case)\n    \"PASCAL_CASE_VAR\"\n\n    iex> Kase.convert(\"this-is-an-example\", :train_case)\n    \"This-Is-An-Example\"\n\n    iex> Kase.convert(\"this_is_cobol_case\", :cobol_case)\n    \"THIS-IS-COBOL-CASE\"\n\n    iex> Kase.convert(\"exampleForDotCase\", :dot_case)\n    \"example.for.dot.case\"\n\n    iex> Kase.convert(\"example.for.flat.case\", :flat_case)\n    \"exampleforflatcase\"","ref":"Kase.Conversor.html#convert/2-examples"},{"type":"function","title":"Supported target cases - Kase.Conversor.convert/2","doc":"- `:camel_case`\n- `:cobol_case`\n- `:dot_case`\n- `:flat_case`\n- `:humanized_case`\n- `:kebab_case`\n- `:pascal_case`\n- `:snake_case`\n- `:train_case`\n- `:upper_case_snake_case`","ref":"Kase.Conversor.html#convert/2-supported-target-cases"},{"type":"function","title":"Kase.Conversor.from_dot_case_to_flat_case/1","doc":"","ref":"Kase.Conversor.html#from_dot_case_to_flat_case/1"},{"type":"module","title":"Kase.Plug.ConvertKeys","doc":"A Plug for converting the casing of request and response keys.\n\nThis plug allows you to convert the keys of incoming JSON requests\nand outgoing JSON responses to various casing styles such as\n`snake_case`, `camelCase`, `PascalCase`, etc.","ref":"Kase.Plug.ConvertKeys.html"},{"type":"module","title":"Usage - Kase.Plug.ConvertKeys","doc":"To use this plug, you can either add it to your router or directly\nin a controller.","ref":"Kase.Plug.ConvertKeys.html#module-usage"},{"type":"module","title":"In Your Router - Kase.Plug.ConvertKeys","doc":"You can use the plug in your router to apply it to specific routes or\nall routes. Here's how you can do that:\n\n```elixir\n  defmodule MyAppWeb.Router do\n    use MyAppWeb, :router\n\n    pipeline :api do\n      plug Kase.Plug.ConvertKeys\n    end\n\n    scope \"/api\", MyAppWeb do\n      pipe_through :api\n\n      get \"/example\", ExampleController, :index\n    end\n  end\n```","ref":"Kase.Plug.ConvertKeys.html#module-in-your-router"},{"type":"module","title":"In a Controller - Kase.Plug.ConvertKeys","doc":"```elixir\n  defmodule MyAppWeb.ExampleController do\n    use MyAppWeb, :controller\n    plug Kase.Plug.ConvertKeys\n\n    def index(conn, _params) do\n      json(conn, %{some_key: \"some_value\"})\n    end\n  end\n```","ref":"Kase.Plug.ConvertKeys.html#module-in-a-controller"},{"type":"module","title":"Options - Kase.Plug.ConvertKeys","doc":"The plug accepts the following options:\n\n  - :request_casing - Specify the casing for incoming request parameters.\n    Accepted values include :snake_case, :camel_case, :pascal_case, etc.\n    Defaults to :snake_case.\n  - :response_casing - Specify the casing for outgoing response\n    parameters. Similar to :request_casing, it accepts the same casing\n    styles and defaults to :snake_case.\n\n#### Example of using Options\n\nHere’s an example of how to specify request and response casing options:\n\n```elixir\n  defmodule MyAppWeb.ExampleController do\n    use MyAppWeb, :controller\n    plug Kase.Plug.ConvertKeys, request_casing: :dot_case, response_casing: :train_case\n\n    def index(conn, _params) do\n      json(conn, %{\"exampleKey\" => \"exampleValue\"})\n    end\n  end\n```\n\nIn this example, incoming parameters will be converted to camelCase, and outgoing\nresponses will be in PascalCase.","ref":"Kase.Plug.ConvertKeys.html#module-options"},{"type":"function","title":"Kase.Plug.ConvertKeys.call/2","doc":"Converts the keys of the request body to the desired casing style.","ref":"Kase.Plug.ConvertKeys.html#call/2"},{"type":"function","title":"Kase.Plug.ConvertKeys.init/1","doc":"Initializes the plug.","ref":"Kase.Plug.ConvertKeys.html#init/1"},{"type":"extras","title":"Käse","doc":"# Käse\n\n[![Kase Package](https://img.shields.io/hexpm/v/kase.svg)](https://hex.pm/packages/kase/1.1.2)\n\nKäse is an Elixir library for converting strings between various casing styles, including\ncamelCase, snake_case, kebab-case, PascalCase, and more. Whether you're working with data from\ndifferent sources or simply want to format strings in a specific way, Käse provides a\nstraightforward API to handle these conversions.","ref":"readme.html"},{"type":"extras","title":"Installation - Käse","doc":"To use Käse in your Elixir project, add it to your `mix.exs` file:\n\n```elixir\ndefp deps do\n  [\n    {:kase, \"~> 1.1.2\"}\n  ]\nend\n```\n\nThen run the following command to install the dependency:\n\n```bash\nmix deps.get\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Käse","doc":"You can convert strings between different casing styles using the `Kase.convert/2` function.\nHere are some examples:","ref":"readme.html#usage"},{"type":"extras","title":"Convert to camelCase - Käse","doc":"```elixir\nKase.convert(\"this_is_an_example\", :camel_case)\n# => \"thisIsAnExample\"\n\nKase.convert(\"ThisIsPascalCase\", :camel_case)\n# => \"thisIsPascalCase\"\n```","ref":"readme.html#convert-to-camelcase"},{"type":"extras","title":"Convert to snake_case - Käse","doc":"```elixir\nKase.convert(\"thisIsAnExample\", :snake_case)\n# => \"this_is_an_example\"\n\nKase.convert(\"ThisIsPascalCase\", :snake_case)\n# => \"this_is_pascal_case\"\n```","ref":"readme.html#convert-to-snake_case"},{"type":"extras","title":"Convert to kebab-case - Käse","doc":"```elixir\nKase.convert(\"thisIsAnExample\", :kebab_case)\n# => \"this-is-an-example\"\n\nKase.convert(\"ThisIsPascalCase\", :kebab_case)\n# => \"this-is-pascal-case\"\n```","ref":"readme.html#convert-to-kebab-case"},{"type":"extras","title":"Convert to PascalCase - Käse","doc":"```elixir\nKase.convert(\"this_is_an_example\", :pascal_case)\n# => \"ThisIsAnExample\"\n\nKase.convert(\"this-is-an-example\", :pascal_case)\n# => \"ThisIsAnExample\"\n```","ref":"readme.html#convert-to-pascalcase"},{"type":"extras","title":"Convert to upper_case_snake_case - Käse","doc":"```elixir\nKase.convert(\"thisIsAnExample\", :upper_case_snake_case)\n# => \"THIS_IS_AN_EXAMPLE\"\n```","ref":"readme.html#convert-to-upper_case_snake_case"},{"type":"extras","title":"Convert to train-case - Käse","doc":"```elixir\nKase.convert(\"thisIsAnExample\", :train_case)\n# => \"This-Is-An-Example\"\n```","ref":"readme.html#convert-to-train-case"},{"type":"extras","title":"Convert to dot.case - Käse","doc":"```elixir\nKase.convert(\"thisIsAnExample\", :dot_case)\n# => \"this.is.an.example\"\n```","ref":"readme.html#convert-to-dot-case"},{"type":"extras","title":"Convert to cobol-case - Käse","doc":"```elixir\nKase.convert(\"thisIsAnExample\", :cobol_case)\n# => \"THIS-IS-AN-EXAMPLE\"\n```","ref":"readme.html#convert-to-cobol-case"},{"type":"extras","title":"Convert to humanized case - Käse","doc":"```elixir\nKase.convert(\"this_is_an_example\", :humanized_case)\n# => \"This is an example\"\n```","ref":"readme.html#convert-to-humanized-case"},{"type":"extras","title":"Convert to flat case - Käse","doc":"```elixir\nKase.convert(\"this_is_an_example\", :flat_case)\n# => \"thisisanexample\"\n```","ref":"readme.html#convert-to-flat-case"},{"type":"extras","title":"Convert Map Keys - Käse","doc":"You can also convert the keys of a map to a desired casing style using Kase.convert/3. This\nfunction accepts an optional :to_atoms option to convert the keys into atoms if desired.\n\n\n```elixir\noriginal_map = %{first_name: \"John\", last_name: \"Doe\"}\nKase.convert(original_map, :kebab_case)\n# => %{\"first-name\" => \"John\", \"last-name\" => \"Doe\"}\n```\n\n#### Convert with keys as atoms\n```elixir\nKase.convert(original_map, :kebab_case, to_atoms: true)\n# => %{\"first-name\": \"John\", \"last-name\": \"Doe\"}\n```","ref":"readme.html#convert-map-keys"},{"type":"extras","title":"Plug for Key Conversion - Käse","doc":"Käse also provides a Plug for automatically converting the keys of incoming request parameters\nand outgoing response data to different casing styles. This is particularly useful in a\nPhoenix application where you want consistent casing for API inputs and outputs. Both request\nand response casing styles default to `:snake_case`.","ref":"readme.html#plug-for-key-conversion"},{"type":"extras","title":"Usage - Käse","doc":"You can add the plug to your router or directly in a controller. \nHere’s an example of how to use it:\n\n```elixir\ndefmodule MyAppWeb.Router do\n  use MyAppWeb, :router\n\n  pipeline :api do\n    plug Kase.Plug.ConvertKeys, request_casing: :flat_case, response_casing: :train_case\n  end\n\n  scope \"/api\", MyAppWeb do\n    pipe_through :api\n\n    get \"/example\", ExampleController, :index\n  end\nend\n```","ref":"readme.html#usage"},{"type":"extras","title":"Contributing - Käse","doc":"Contributions are welcome! If you have suggestions for improvements or find bugs, please open\nan issue or submit a pull request.\n\n1. Fork the project\n2. Create your feature branch: `git checkout -b feature/my-new-feature`\n3. Commit your changes: `git commit -m 'Add some feature'`\n4. Push to the branch: `git push origin feature/my-new-feature`\n5. Open a pull request","ref":"readme.html#contributing"},{"type":"extras","title":"License - Käse","doc":"Käse is released under the MIT License. See the [LICENSE](LICENSE) file for more information.","ref":"readme.html#license"},{"type":"extras","title":"Acknowledgments - Käse","doc":"Thank you for using Käse! We hope it helps make your string handling in Elixir easier and more\nenjoyable.","ref":"readme.html#acknowledgments"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) [2024] [vicentedpsantos]\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\n1. The above copyright notice and this permission notice shall be included in\n   all copies or substantial portions of the Software.\n\n2. THE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\n   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\n   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\n   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\n   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\n   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\n   SOFTWARE.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}